@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 package    # hide from PAUSE
@@ -124,6 +124,21 @@ use base qw(Rose::Object);
 use Rose::Object::MakeMethods::Generic(scalar => 'myattr');
 
 
+#package    # hide from PAUSE
+#  WithBadgerClass;
+#use Badger::Class
+#    base     => 'Badger::Base',
+#    mutators => 'myattr';
+
+
+package    # hide from PAUSE
+  WithRubyishAttribute;
+use Rubyish::Attribute ':all';
+sub new { bless {}, shift }
+
+attr_accessor(["myattr"]);
+
+
 1;
 
 
